# frozen_string_literal: true

module BtcPay
  module Client
    module Api
      class StoreInvoices < Base
        PATH = '/stores/:store_id/invoices'

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_GetInvoices
        def all(store_id, **opts)
          client.get(store_path(store_id), options: opts)
        end

        alias index all

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_CreateInvoice
        def create(store_id, payload, **opts)
          client.post(store_path(store_id), payload: payload, options: opts)
        end

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_GetInvoice
        def get(store_id, invoice_id, **opts)
          client.get(store_path(store_id, invoice_id), options: opts)
        end

        alias find get

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_ArchiveInvoice
        def delete(store_id, invoice_id, **opts)
          client.delete(store_path(store_id, invoice_id), options: opts)
        end

        alias archive delete

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_MarkInvoiceStatus
        # @see https://github.com/btcpayserver/btcpayserver/blob/master/BTCPayServer.Client/Models/InvoiceStatus.cs
        def update_status(store_id, invoice_id, status = 'Complete', **opts)
          client.post(store_path(store_id, invoice_id, 'status'), payload: { status: status }, options: opts)
        end

        # @see https://docs.btcpayserver.org/API/Greenfield/v1/#operation/Invoices_UnarchiveInvoice
        def unarchive(store_id, invoice_id, **opts)
          client.post(store_path(store_id, invoice_id, 'unarchive'), payload: {}, options: opts)
        end

        protected

        def set_base_path
          @base_path = PATH.dup
        end
      end
    end
  end
end
